function noop() { }

class EventEmitter {
    constructor() {
        this.events = [];
    }
    on(eventName, listener = noop, context) {
        this.events.push({ eventName, listener, context });
        return this;
    }
    off(eventName, listener) {
        const matched = this.events.findIndex(regEvent => regEvent.eventName === eventName && (listener ? regEvent.listener === listener : true));
        if (!~matched) {
            return;
        }
        this.events.splice(matched, 1);
        return this;
    }
    once(eventName, listener = noop, context) {
        const onceWrapper = (...values) => {
            this.off(eventName, onceWrapper);
            listener.apply(context || listener, values);
        };
        this.on(eventName, onceWrapper, context);
        return this;
    }
    emit(eventName, ...values) {
        this.events.forEach(regEvent => {
            if (regEvent.eventName === eventName) {
                regEvent.listener.apply(regEvent.context || regEvent.listener, values);
            }
        });
        return this;
    }
    fire(eventName, ...values) {
        this.emit(eventName, values);
        return this;
    }
}

/*
 * Public API Surface of @nonoll/code-snippet/event
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EventEmitter };
//# sourceMappingURL=nonoll-code-snippet-event.js.map
